@@ -50,7 +50,7 @@ signals:
     void conversionStarted();
     void conversionCompleted();
     void conversionFailed();
-    void playbackStarted();
+    void playbackStarted(const QString &url);
 };
 
 #endif // CONTROLLER_H
