@@ -5,7 +5,7 @@
     <name>AboutDialog</name>
     <message>
         <location filename="../AboutDialog.qml" line="44"/>
-        <source>cuteTube-QML - 0.7.0</source>
+        <source>cuteTube-QML - 0.7.1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -95,13 +95,13 @@
 <context>
     <name>ArchiveListView</name>
     <message>
-        <location filename="../ArchiveListView.qml" line="17"/>
+        <location filename="../ArchiveListView.qml" line="27"/>
         <source>Deleted from archive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="20"/>
-        <location filename="../ArchiveListView.qml" line="35"/>
+        <location filename="../ArchiveListView.qml" line="30"/>
+        <location filename="../ArchiveListView.qml" line="47"/>
         <source>Unable to delete from archive</source>
         <translation type="unfinished"></translation>
     </message>
@@ -340,7 +340,12 @@
 <context>
     <name>PlaylistVideosView</name>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="75"/>
+        <location filename="../PlaylistVideosView.qml" line="59"/>
+        <source>Video(s) deleted from playlist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../PlaylistVideosView.qml" line="80"/>
         <source>No videos found</source>
         <translation></translation>
     </message>
@@ -742,8 +747,8 @@
     </message>
     <message>
         <location filename="../SubscriptionsView.qml" line="45"/>
-        <source>You have unsubscribed to &apos;</source>
-        <translation></translation>
+        <source>You have unsubscribed to this channel</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../SubscriptionsView.qml" line="104"/>
@@ -928,37 +933,37 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="115"/>
+        <location filename="../UserVideosView.qml" line="117"/>
         <source>You have subscribed to &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="119"/>
+        <location filename="../UserVideosView.qml" line="121"/>
         <source>You have unsubscribed to &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="139"/>
+        <location filename="../UserVideosView.qml" line="141"/>
         <source>No videos found</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="198"/>
+        <location filename="../UserVideosView.qml" line="200"/>
         <source>Subscribers</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="212"/>
+        <location filename="../UserVideosView.qml" line="214"/>
         <source>Videos</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="235"/>
+        <location filename="../UserVideosView.qml" line="237"/>
         <source>Unsubscribe</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="235"/>
+        <location filename="../UserVideosView.qml" line="237"/>
         <source>Subscribe</source>
         <translation></translation>
     </message>
@@ -988,7 +993,7 @@
     <message>
         <location filename="../VideoInfoView.qml" line="443"/>
         <location filename="../VideoInfoView.qml" line="467"/>
-        <location filename="../VideoInfoView.qml" line="572"/>
+        <location filename="../VideoInfoView.qml" line="579"/>
         <source>You are not signed in to a YouTube account</source>
         <translation></translation>
     </message>
@@ -1035,17 +1040,22 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="584"/>
+        <location filename="../VideoInfoView.qml" line="524"/>
+        <source>No tags</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../VideoInfoView.qml" line="591"/>
         <source>No comments</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="584"/>
+        <location filename="../VideoInfoView.qml" line="591"/>
         <source> comments</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="677"/>
+        <location filename="../VideoInfoView.qml" line="684"/>
         <source>No related videos</source>
         <translation></translation>
     </message>
@@ -1071,7 +1081,12 @@
 <context>
     <name>VideoListView</name>
     <message>
-        <location filename="../VideoListView.qml" line="72"/>
+        <location filename="../VideoListView.qml" line="70"/>
+        <source>Video(s) deleted from favourites</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../VideoListView.qml" line="92"/>
         <source>No videos found</source>
         <translation></translation>
     </message>
@@ -1121,8 +1136,7 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="387"/>
-        <location filename="../../../youtube.cpp" line="424"/>
+        <location filename="../../../youtube.cpp" line="388"/>
         <source>Error: Unable to retrieve video</source>
         <translation></translation>
     </message>
@@ -1155,72 +1169,72 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="206"/>
+        <location filename="../main.qml" line="207"/>
         <source>Audio</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="211"/>
+        <location filename="../main.qml" line="212"/>
         <source>Conversion of &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="211"/>
+        <location filename="../main.qml" line="212"/>
         <source>&apos; failed</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>High quality</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>Mobile</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>360p</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>480p</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>720p</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Queued</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Paused</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Downloading</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="395"/>
+        <location filename="../main.qml" line="396"/>
         <source>Most Recent</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="396"/>
+        <location filename="../main.qml" line="397"/>
         <source>Most Viewed</source>
         <translation></translation>
     </message>
@@ -1228,37 +1242,37 @@
 <context>
     <name>mainscripts</name>
     <message>
-        <location filename="../scripts/mainscripts.js" line="123"/>
+        <location filename="../scripts/mainscripts.js" line="143"/>
         <source>My Channel</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="138"/>
+        <location filename="../scripts/mainscripts.js" line="158"/>
         <source>Archive</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="177"/>
+        <location filename="../scripts/mainscripts.js" line="197"/>
         <source>My Playlists</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="187"/>
+        <location filename="../scripts/mainscripts.js" line="207"/>
         <source>My Subscriptions</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="200"/>
+        <location filename="../scripts/mainscripts.js" line="220"/>
         <source>Video Info</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="210"/>
+        <location filename="../scripts/mainscripts.js" line="230"/>
         <source>Video Playback</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="223"/>
+        <location filename="../scripts/mainscripts.js" line="243"/>
         <source>Search </source>
         <translation></translation>
     </message>
