@@ -40,9 +40,13 @@
         <translation type="obsolete">cuteTube-QML - 0.6.5 in deutsch</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.7.0</source>
-        <translation>cuteTube-QML - 0.7.0 in deutsch</translation>
+        <translation type="obsolete">cuteTube-QML - 0.7.0 in deutsch</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.7.1</source>
+        <translation type="unfinished">cuteTube-QML - 0.7.1 in deutsch</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -167,13 +171,13 @@
         <translation type="obsolete">Vom Gerät löschen</translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="17"/>
+        <location filename="../ArchiveListView.qml" line="27"/>
         <source>Deleted from archive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="20"/>
-        <location filename="../ArchiveListView.qml" line="35"/>
+        <location filename="../ArchiveListView.qml" line="30"/>
+        <location filename="../ArchiveListView.qml" line="47"/>
         <source>Unable to delete from archive</source>
         <translation type="unfinished"></translation>
     </message>
@@ -537,7 +541,12 @@
         <translation type="obsolete">In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="75"/>
+        <location filename="../PlaylistVideosView.qml" line="59"/>
+        <source>Video(s) deleted from playlist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../PlaylistVideosView.qml" line="80"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
@@ -955,8 +964,12 @@
     </message>
     <message>
         <location filename="../SubscriptionsView.qml" line="45"/>
+        <source>You have unsubscribed to this channel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>You have unsubscribed to &apos;</source>
-        <translation>Du hast ein Abonnement bei </translation>
+        <translation type="obsolete">Du hast ein Abonnement bei </translation>
     </message>
     <message>
         <source>Latest Subscription Videos</source>
@@ -1153,12 +1166,12 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="115"/>
+        <location filename="../UserVideosView.qml" line="117"/>
         <source>You have subscribed to &apos;</source>
         <translation>Du hast ein Abonnement bei</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="119"/>
+        <location filename="../UserVideosView.qml" line="121"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Abonnement gekündigt bei</translation>
     </message>
@@ -1187,27 +1200,27 @@
         <translation type="obsolete">In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="139"/>
+        <location filename="../UserVideosView.qml" line="141"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="198"/>
+        <location filename="../UserVideosView.qml" line="200"/>
         <source>Subscribers</source>
         <translation>Abonnenten</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="212"/>
+        <location filename="../UserVideosView.qml" line="214"/>
         <source>Videos</source>
         <translation>Videos</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="235"/>
+        <location filename="../UserVideosView.qml" line="237"/>
         <source>Unsubscribe</source>
         <translation>Abonnement kündigen</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="235"/>
+        <location filename="../UserVideosView.qml" line="237"/>
         <source>Subscribe</source>
         <translation>Abonnieren</translation>
     </message>
@@ -1253,7 +1266,7 @@
     <message>
         <location filename="../VideoInfoView.qml" line="443"/>
         <location filename="../VideoInfoView.qml" line="467"/>
-        <location filename="../VideoInfoView.qml" line="572"/>
+        <location filename="../VideoInfoView.qml" line="579"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Nicht bei einem YouTube Konto angemeldet</translation>
     </message>
@@ -1300,17 +1313,22 @@
         <translation>Tags</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="584"/>
+        <location filename="../VideoInfoView.qml" line="524"/>
+        <source>No tags</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../VideoInfoView.qml" line="591"/>
         <source>No comments</source>
         <translation>Keine Kommentare</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="584"/>
+        <location filename="../VideoInfoView.qml" line="591"/>
         <source> comments</source>
         <translation>Kommentare</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="677"/>
+        <location filename="../VideoInfoView.qml" line="684"/>
         <source>No related videos</source>
         <translation>Keine ähnlichen Videos</translation>
     </message>
@@ -1360,7 +1378,12 @@
         <translation type="obsolete">In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="72"/>
+        <location filename="../VideoListView.qml" line="70"/>
+        <source>Video(s) deleted from favourites</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../VideoListView.qml" line="92"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
@@ -1508,8 +1531,7 @@
         <translation>Upload ist komplett</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="387"/>
-        <location filename="../../../youtube.cpp" line="424"/>
+        <location filename="../../../youtube.cpp" line="388"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Fehler: Kann Video nicht empfangen</translation>
     </message>
@@ -1554,72 +1576,72 @@
         <translation type="obsolete">Konvertiere</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="206"/>
+        <location filename="../main.qml" line="207"/>
         <source>Audio</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="211"/>
+        <location filename="../main.qml" line="212"/>
         <source>Conversion of &apos;</source>
         <translation>Unterhaltung zwischen &apos;</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="211"/>
+        <location filename="../main.qml" line="212"/>
         <source>&apos; failed</source>
         <translation>&apos; gescheitert</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>High quality</source>
         <translation>Hohe qualität</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>Mobile</source>
         <translation>Mobil</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>360p</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>480p</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>720p</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Queued</source>
         <translation>in Warteschlange</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Paused</source>
         <translation>Pausiert</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Downloading</source>
         <translation>am Herrunterladen</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Failed</source>
         <translation>Fehlgeschlagen</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="395"/>
+        <location filename="../main.qml" line="396"/>
         <source>Most Recent</source>
         <translation>Aktuellste Videos</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="396"/>
+        <location filename="../main.qml" line="397"/>
         <source>Most Viewed</source>
         <translation>Meistgesehen</translation>
     </message>
@@ -1631,32 +1653,32 @@
         <translation type="obsolete">Media Player</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="123"/>
+        <location filename="../scripts/mainscripts.js" line="143"/>
         <source>My Channel</source>
         <translation>Mein Kanal</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="138"/>
+        <location filename="../scripts/mainscripts.js" line="158"/>
         <source>Archive</source>
         <translation>Archiv</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="177"/>
+        <location filename="../scripts/mainscripts.js" line="197"/>
         <source>My Playlists</source>
         <translation>Mein Wiedergabelisten</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="187"/>
+        <location filename="../scripts/mainscripts.js" line="207"/>
         <source>My Subscriptions</source>
         <translation>Mein Abonnement</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="200"/>
+        <location filename="../scripts/mainscripts.js" line="220"/>
         <source>Video Info</source>
         <translation>Video Info</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="210"/>
+        <location filename="../scripts/mainscripts.js" line="230"/>
         <source>Video Playback</source>
         <translation>Video abspielen</translation>
     </message>
@@ -1681,7 +1703,7 @@
         <translation type="obsolete">bewertung</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="223"/>
+        <location filename="../scripts/mainscripts.js" line="243"/>
         <source>Search </source>
         <translation>Suchlauf</translation>
     </message>
