@@ -5,7 +5,7 @@
     <name>AboutDialog</name>
     <message>
         <location filename="../AboutDialog.qml" line="44"/>
-        <source>cuteTube-QML - 0.7.0</source>
+        <source>cuteTube-QML - 0.7.1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -103,13 +103,13 @@
         <translation type="obsolete">Cancella dal dispositivo</translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="17"/>
+        <location filename="../ArchiveListView.qml" line="27"/>
         <source>Deleted from archive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="20"/>
-        <location filename="../ArchiveListView.qml" line="35"/>
+        <location filename="../ArchiveListView.qml" line="30"/>
+        <location filename="../ArchiveListView.qml" line="47"/>
         <source>Unable to delete from archive</source>
         <translation type="unfinished"></translation>
     </message>
@@ -437,7 +437,12 @@
         <translation type="obsolete">Copia negli appunti</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="75"/>
+        <location filename="../PlaylistVideosView.qml" line="59"/>
+        <source>Video(s) deleted from playlist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../PlaylistVideosView.qml" line="80"/>
         <source>No videos found</source>
         <translation>Nessun video trovato</translation>
     </message>
@@ -855,8 +860,12 @@
     </message>
     <message>
         <location filename="../SubscriptionsView.qml" line="45"/>
+        <source>You have unsubscribed to this channel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>You have unsubscribed to &apos;</source>
-        <translation>Ti sei cancellato da &apos;</translation>
+        <translation type="obsolete">Ti sei cancellato da &apos;</translation>
     </message>
     <message>
         <source>Latest Subscription Videos</source>
@@ -1045,12 +1054,12 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="115"/>
+        <location filename="../UserVideosView.qml" line="117"/>
         <source>You have subscribed to &apos;</source>
         <translation>Ti sei iscritto a &apos;</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="119"/>
+        <location filename="../UserVideosView.qml" line="121"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Ti sei cancellato da &apos;</translation>
     </message>
@@ -1075,27 +1084,27 @@
         <translation type="obsolete">Copia negli appunti</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="139"/>
+        <location filename="../UserVideosView.qml" line="141"/>
         <source>No videos found</source>
         <translation>Nessun video trovato</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="198"/>
+        <location filename="../UserVideosView.qml" line="200"/>
         <source>Subscribers</source>
         <translation>Iscritti</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="212"/>
+        <location filename="../UserVideosView.qml" line="214"/>
         <source>Videos</source>
         <translation>Video</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="235"/>
+        <location filename="../UserVideosView.qml" line="237"/>
         <source>Unsubscribe</source>
         <translation>Cancellati</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="235"/>
+        <location filename="../UserVideosView.qml" line="237"/>
         <source>Subscribe</source>
         <translation>Iscriviti</translation>
     </message>
@@ -1141,7 +1150,7 @@
     <message>
         <location filename="../VideoInfoView.qml" line="443"/>
         <location filename="../VideoInfoView.qml" line="467"/>
-        <location filename="../VideoInfoView.qml" line="572"/>
+        <location filename="../VideoInfoView.qml" line="579"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Non hai effettuato l&apos;accesso con un account YouTube</translation>
     </message>
@@ -1188,17 +1197,22 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="584"/>
+        <location filename="../VideoInfoView.qml" line="524"/>
+        <source>No tags</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../VideoInfoView.qml" line="591"/>
         <source>No comments</source>
         <translation>Nessun commento</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="584"/>
+        <location filename="../VideoInfoView.qml" line="591"/>
         <source> comments</source>
         <translation> commenti</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="677"/>
+        <location filename="../VideoInfoView.qml" line="684"/>
         <source>No related videos</source>
         <translation>Nessun video correlato</translation>
     </message>
@@ -1244,7 +1258,12 @@
         <translation type="obsolete">Copia negli appunti</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="72"/>
+        <location filename="../VideoListView.qml" line="70"/>
+        <source>Video(s) deleted from favourites</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../VideoListView.qml" line="92"/>
         <source>No videos found</source>
         <translation>Nessun video trovato</translation>
     </message>
@@ -1364,8 +1383,7 @@
         <translation>Caricamento completato</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="387"/>
-        <location filename="../../../youtube.cpp" line="424"/>
+        <location filename="../../../youtube.cpp" line="388"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Errore: Impossibile recuperare il video</translation>
     </message>
@@ -1406,72 +1424,72 @@
         <translation type="obsolete">In Conversione</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="206"/>
+        <location filename="../main.qml" line="207"/>
         <source>Audio</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="211"/>
+        <location filename="../main.qml" line="212"/>
         <source>Conversion of &apos;</source>
         <translation>Conversione di &apos;</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="211"/>
+        <location filename="../main.qml" line="212"/>
         <source>&apos; failed</source>
         <translation>&apos; fallita</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>High quality</source>
         <translation>Altà qualità</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>Mobile</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>360p</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>480p</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>720p</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Queued</source>
         <translation>In Coda</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Paused</source>
         <translation>In Pausa</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Downloading</source>
         <translation>In Download</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Failed</source>
         <translation>Fallito</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="395"/>
+        <location filename="../main.qml" line="396"/>
         <source>Most Recent</source>
         <translation>I Più Recenti</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="396"/>
+        <location filename="../main.qml" line="397"/>
         <source>Most Viewed</source>
         <translation>I Più Visti</translation>
     </message>
@@ -1479,32 +1497,32 @@
 <context>
     <name>mainscripts</name>
     <message>
-        <location filename="../scripts/mainscripts.js" line="123"/>
+        <location filename="../scripts/mainscripts.js" line="143"/>
         <source>My Channel</source>
         <translation>Il Mio Canale</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="138"/>
+        <location filename="../scripts/mainscripts.js" line="158"/>
         <source>Archive</source>
         <translation>Archivio</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="177"/>
+        <location filename="../scripts/mainscripts.js" line="197"/>
         <source>My Playlists</source>
         <translation>Le Mie Playlist</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="187"/>
+        <location filename="../scripts/mainscripts.js" line="207"/>
         <source>My Subscriptions</source>
         <translation>Le Mie Iscrizioni</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="200"/>
+        <location filename="../scripts/mainscripts.js" line="220"/>
         <source>Video Info</source>
         <translation>Info Video</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="210"/>
+        <location filename="../scripts/mainscripts.js" line="230"/>
         <source>Video Playback</source>
         <translation>Riproduzione Video</translation>
     </message>
@@ -1525,7 +1543,7 @@
         <translation type="obsolete">voto</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="223"/>
+        <location filename="../scripts/mainscripts.js" line="243"/>
         <source>Search </source>
         <translation>Cerca </translation>
     </message>
