@@ -16,9 +16,13 @@
         <translation type="obsolete">cuteTube-QML - 0.6.5 - PL</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.7.0</source>
-        <translation type="unfinished">cuteTube-QML - 0.7.0 - PL</translation>
+        <translation type="obsolete">cuteTube-QML - 0.7.0 - PL</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.7.1</source>
+        <translation type="unfinished">cuteTube-QML - 0.7.1 - PL</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -119,13 +123,13 @@
         <translation type="obsolete">Usuń z urządzenia</translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="17"/>
+        <location filename="../ArchiveListView.qml" line="27"/>
         <source>Deleted from archive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="20"/>
-        <location filename="../ArchiveListView.qml" line="35"/>
+        <location filename="../ArchiveListView.qml" line="30"/>
+        <location filename="../ArchiveListView.qml" line="47"/>
         <source>Unable to delete from archive</source>
         <translation type="unfinished"></translation>
     </message>
@@ -461,7 +465,12 @@
         <translation type="obsolete">Skopiuj do schowka</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="75"/>
+        <location filename="../PlaylistVideosView.qml" line="59"/>
+        <source>Video(s) deleted from playlist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../PlaylistVideosView.qml" line="80"/>
         <source>No videos found</source>
         <translation>Nie znaleziono plików wideo</translation>
     </message>
@@ -879,8 +888,12 @@
     </message>
     <message>
         <location filename="../SubscriptionsView.qml" line="45"/>
+        <source>You have unsubscribed to this channel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>You have unsubscribed to &apos;</source>
-        <translation>Anulowałeś subskrypcje &apos;</translation>
+        <translation type="obsolete">Anulowałeś subskrypcje &apos;</translation>
     </message>
     <message>
         <source>Latest Subscription Videos</source>
@@ -1069,12 +1082,12 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="115"/>
+        <location filename="../UserVideosView.qml" line="117"/>
         <source>You have subscribed to &apos;</source>
         <translation>Zasubskrybowałeś się do &apos;</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="119"/>
+        <location filename="../UserVideosView.qml" line="121"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Anulowałeś subskrybcje &apos;</translation>
     </message>
@@ -1103,27 +1116,27 @@
         <translation type="obsolete">Skopiuj do schowka</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="139"/>
+        <location filename="../UserVideosView.qml" line="141"/>
         <source>No videos found</source>
         <translation>Brak plików wideo</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="198"/>
+        <location filename="../UserVideosView.qml" line="200"/>
         <source>Subscribers</source>
         <translation>Subskrybenci</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="212"/>
+        <location filename="../UserVideosView.qml" line="214"/>
         <source>Videos</source>
         <translation>Pliki wideo</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="235"/>
+        <location filename="../UserVideosView.qml" line="237"/>
         <source>Unsubscribe</source>
         <translation>Wypisz z subskrybcji</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="235"/>
+        <location filename="../UserVideosView.qml" line="237"/>
         <source>Subscribe</source>
         <translation>Zapisz do subskrybcji</translation>
     </message>
@@ -1169,7 +1182,7 @@
     <message>
         <location filename="../VideoInfoView.qml" line="443"/>
         <location filename="../VideoInfoView.qml" line="467"/>
-        <location filename="../VideoInfoView.qml" line="572"/>
+        <location filename="../VideoInfoView.qml" line="579"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Nie jesteś zalogowany do swojego konta YouTube</translation>
     </message>
@@ -1216,17 +1229,22 @@
         <translation>Tagi</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="584"/>
+        <location filename="../VideoInfoView.qml" line="524"/>
+        <source>No tags</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../VideoInfoView.qml" line="591"/>
         <source>No comments</source>
         <translation>Brak komentarzy</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="584"/>
+        <location filename="../VideoInfoView.qml" line="591"/>
         <source> comments</source>
         <translation> komentarzy</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="677"/>
+        <location filename="../VideoInfoView.qml" line="684"/>
         <source>No related videos</source>
         <translation>Brak podobnych plików wideo</translation>
     </message>
@@ -1276,7 +1294,12 @@
         <translation type="obsolete">Skopiuj do schowka</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="72"/>
+        <location filename="../VideoListView.qml" line="70"/>
+        <source>Video(s) deleted from favourites</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../VideoListView.qml" line="92"/>
         <source>No videos found</source>
         <translation>Brak plików wideo</translation>
     </message>
@@ -1333,8 +1356,7 @@
         <translation>Wysyłanie ukończone</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="387"/>
-        <location filename="../../../youtube.cpp" line="424"/>
+        <location filename="../../../youtube.cpp" line="388"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Błąd: Nie można odebrać wideo</translation>
     </message>
@@ -1379,72 +1401,72 @@
         <translation type="obsolete">Konwersja</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="206"/>
+        <location filename="../main.qml" line="207"/>
         <source>Audio</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="211"/>
+        <location filename="../main.qml" line="212"/>
         <source>Conversion of &apos;</source>
         <translation>Konwersja &apos;</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="211"/>
+        <location filename="../main.qml" line="212"/>
         <source>&apos; failed</source>
         <translation>&apos; nieudana</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>High quality</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>Mobile</source>
         <translation type="unfinished">Mobilny</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>360p</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>480p</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>720p</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Queued</source>
         <translation>W Kolejce</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Paused</source>
         <translation>Wstrzymany</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Downloading</source>
         <translation type="unfinished">Pobieranie</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Failed</source>
         <translation type="unfinished">Nieudany</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="395"/>
+        <location filename="../main.qml" line="396"/>
         <source>Most Recent</source>
         <translation>Ostatnio dodane</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="396"/>
+        <location filename="../main.qml" line="397"/>
         <source>Most Viewed</source>
         <translation>Najczęściej oglądane</translation>
     </message>
@@ -1456,32 +1478,32 @@
         <translation type="obsolete">Odtwarzacz</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="123"/>
+        <location filename="../scripts/mainscripts.js" line="143"/>
         <source>My Channel</source>
         <translation>Mój kanał</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="138"/>
+        <location filename="../scripts/mainscripts.js" line="158"/>
         <source>Archive</source>
         <translation>Archiwum</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="177"/>
+        <location filename="../scripts/mainscripts.js" line="197"/>
         <source>My Playlists</source>
         <translation>Moje listy odtwarzania</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="187"/>
+        <location filename="../scripts/mainscripts.js" line="207"/>
         <source>My Subscriptions</source>
         <translation>Moje Subskrybcje</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="200"/>
+        <location filename="../scripts/mainscripts.js" line="220"/>
         <source>Video Info</source>
         <translation>Informacja o Wideo</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="210"/>
+        <location filename="../scripts/mainscripts.js" line="230"/>
         <source>Video Playback</source>
         <translation>Odtwarzanie Wideo</translation>
     </message>
@@ -1506,7 +1528,7 @@
         <translation type="obsolete">oceny</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="223"/>
+        <location filename="../scripts/mainscripts.js" line="243"/>
         <source>Search </source>
         <translation>Wyszukaj </translation>
     </message>
