@@ -81,19 +81,37 @@ function addVideosToDownloads(convertToAudio) {
 
 function addVideosToPlaylist(playlistId) {
     closeDialogs();
+    toggleBusy(true);
     for (var i = 0; i < videoList.checkList.length; i++) {
         var videoId = videoListModel.get(videoList.checkList[i]).videoId;
-        toggleBusy(true);
         YouTube.addToPlaylist(videoId, playlistId);
     }
     videoList.checkList = [];
 }
 
+function deleteVideosFromPlaylist() {
+    if (videoList.checkList.length > 0) {
+        if (userIsSignedIn()) {
+            toggleBusy(true);
+            for (var i = 0; i < videoList.checkList.length; i++) {
+                var splitId = videoListModel.get(videoList.checkList[i]).id.split(":");
+                var playlistId = splitId[3];
+                var playlistVideoId = splitId[4];
+                YouTube.deleteFromPlaylist(playlistId, playlistVideoId);
+            }
+        }
+        else {
+            displayMessage("You are not signed in to a YouTube account");
+        }
+        videoList.checkList = [];
+    }
+}
+
 function addVideosToFavourites() {
     if (userIsSignedIn()) {
+        toggleBusy(true);
         for (var i = 0; i < videoList.checkList.length; i++) {
             var videoId = videoListModel.get(videoList.checkList[i]).videoId;
-            toggleBusy(true);
             YouTube.addToFavourites(videoId);
         }
     }
@@ -104,6 +122,22 @@ function addVideosToFavourites() {
     videoList.checkList = [];
 }
 
+function deleteVideosFromFavourites() {
+    if (videoList.checkList.length > 0) {
+        if (userIsSignedIn()) {
+            toggleBusy(true);
+            for (var i = 0; i < videoList.checkList.length; i++) {
+                var favouriteId = videoListModel.get(videoList.checkList[i]).id.split(":")[3];
+                YouTube.deleteFromFavourites(favouriteId);
+            }
+        }
+        else {
+            displayMessage("You are not signed in to a YouTube account");
+        }
+        videoList.checkList = [];
+    }
+}
+
 function copyVideosToClipboard() {
     var urls = "";
     for (var i = 0; i < videoList.checkList.length; i++) {
