@@ -56,7 +56,6 @@ private slots:
     void deleteRequest(const QUrl &url);
     void postFinished();
     void parseVideoPage(QNetworkReply *reply);
-    void parseVideoPage();
 
 private:
     QNetworkAccessManager *nam;
@@ -79,7 +78,9 @@ signals:
     void accessTokenChanged(const QString &token);
     void postSuccessful();
     void addedToFavourites();
+    void deletedFromFavourites();
     void addedToPlaylist();
+    void deletedFromPlaylist();
     void playlistCreated();
     void subscribed();
     void unsubscribed();
